==> mozc-2.17.2313.102.tar.xz: mozc-2.17.2313.102/src/storage/encrypted_string_storage.h <==
// Copyright 2010-2016, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_STORAGE_ENCRYPTED_STRING_STORAGE_H_
#define MOZC_STORAGE_ENCRYPTED_STRING_STORAGE_H_

#include <string>

#include "base/port.h"

namespace mozc {
namespace storage {

class StringStorageInterface {
 public:
  virtual ~StringStorageInterface() {}

  virtual bool Load(string *output) const = 0;
  virtual bool Save(const string &input) const = 0;
};

class EncryptedStringStorage : public StringStorageInterface {
 public:
  explicit EncryptedStringStorage(const string &filename);
  virtual ~EncryptedStringStorage();

  virtual bool Load(string *output) const;
  virtual bool Save(const string &input) const;

 protected:
  virtual bool Encrypt(const string &salt, string *data) const;
  virtual bool Decrypt(const string &salt, string *data) const;

 private:
  string filename_;

  DISALLOW_COPY_AND_ASSIGN(EncryptedStringStorage);
};

}  // namespace storage
}  // namespace mozc

#endif  // MOZC_STORAGE_ENCRYPTED_STRING_STORAGE_H_

==> mozc-2.26.4282.100.tar.xz: mozc-2.26.4282.100/src/storage/encrypted_string_storage.h <==
// Copyright 2010-2021, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_STORAGE_ENCRYPTED_STRING_STORAGE_H_
#define MOZC_STORAGE_ENCRYPTED_STRING_STORAGE_H_

#include <string>

#include "base/port.h"

namespace mozc {
namespace storage {

class StringStorageInterface {
 public:
  virtual ~StringStorageInterface() {}

  virtual bool Load(std::string *output) const = 0;
  virtual bool Save(const std::string &input) const = 0;
};

class EncryptedStringStorage : public StringStorageInterface {
 public:
  explicit EncryptedStringStorage(const std::string &filename);
  ~EncryptedStringStorage() override;

  bool Load(std::string *output) const override;
  bool Save(const std::string &input) const override;

 protected:
  virtual bool Encrypt(const std::string &salt, std::string *data) const;
  virtual bool Decrypt(const std::string &salt, std::string *data) const;

 private:
  std::string filename_;

  DISALLOW_COPY_AND_ASSIGN(EncryptedStringStorage);
};

}  // namespace storage
}  // namespace mozc

#endif  // MOZC_STORAGE_ENCRYPTED_STRING_STORAGE_H_
